FadeShimmerList class

A widget that creates a list of shimmer items, useful for loading states in lists

Inheritance

Constructors

FadeShimmerList({Key? key, required int itemCount, required double itemHeight, double? itemWidth, double spacing = 16.0, EdgeInsetsGeometry padding = const EdgeInsets.all(16.0), FadeTheme? fadeTheme, Color? highlightColor, Color? baseColor, double radius = 8.0, bool useGradient = false, ShimmerDirection shimmerDirection = ShimmerDirection.leftToRight, int animationDuration = 1200, bool staggered = true, int staggeredDelay = 100})
const

Properties

animationDuration int
The duration of the animation in milliseconds
final
baseColor Color?
The base color for the shimmer items. If provided, overrides the theme's base color.
final
fadeTheme FadeTheme?
The theme for the shimmer items. If baseColor or highlightColor are provided, they override the theme colors.
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor Color?
The highlight color for the shimmer items. If provided, overrides the theme's highlight color.
final
itemCount int
The number of shimmer items to display
final
itemHeight double
The height of each shimmer item
final
itemWidth double?
The width of each shimmer item (defaults to full width)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry
The padding around the list
final
radius double
The border radius for the shimmer items
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shimmerDirection ShimmerDirection
The direction of the shimmer animation
final
spacing double
The space between items
final
staggered bool
Whether to stagger the animations
final
staggeredDelay int
The delay between staggered animations in milliseconds
final
useGradient bool
Whether to use a gradient effect
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited